==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/systests/microprofile/client/async/src/test/java/org/apache/cxf/systest/microprofile/rest/client/mock/ThreadLocalClientFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.microprofile.rest.client.mock;

import java.io.IOException;
import java.util.List;

import javax.ws.rs.client.ClientRequestContext;
import javax.ws.rs.client.ClientRequestFilter;
import javax.ws.rs.client.ClientResponseContext;
import javax.ws.rs.client.ClientResponseFilter;

public class ThreadLocalClientFilter implements ClientRequestFilter, ClientResponseFilter {

    /** {@inheritDoc}*/
    @Override
    public void filter(ClientRequestContext requestContext) throws IOException {
        List<String> list = AsyncInvocationInterceptorFactoryTestImpl.OUTBOUND.get();
        list.add(ThreadLocalClientFilter.class.getSimpleName());
    }

    /** {@inheritDoc}*/
    @Override
    public void filter(ClientRequestContext requestContext, ClientResponseContext responseContext)
        throws IOException {
        List<String> list = AsyncInvocationInterceptorFactoryTestImpl.INBOUND.get();
        list.add(ThreadLocalClientFilter.class.getSimpleName());
        responseContext.getHeaders().put("CXFTestResponse", list);
    }

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/systests/microprofile/client/async/src/test/java/org/apache/cxf/systest/microprofile/rest/client/mock/ThreadLocalClientFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.microprofile.rest.client.mock;

import java.io.IOException;
import java.util.List;

import jakarta.ws.rs.client.ClientRequestContext;
import jakarta.ws.rs.client.ClientRequestFilter;
import jakarta.ws.rs.client.ClientResponseContext;
import jakarta.ws.rs.client.ClientResponseFilter;

public class ThreadLocalClientFilter implements ClientRequestFilter, ClientResponseFilter {

    /** {@inheritDoc}*/
    @Override
    public void filter(ClientRequestContext requestContext) throws IOException {
        List<String> list = AsyncInvocationInterceptorFactoryTestImpl.OUTBOUND.get();
        list.add(ThreadLocalClientFilter.class.getSimpleName());
    }

    /** {@inheritDoc}*/
    @Override
    public void filter(ClientRequestContext requestContext, ClientResponseContext responseContext)
        throws IOException {
        List<String> list = AsyncInvocationInterceptorFactoryTestImpl.INBOUND.get();
        list.add(ThreadLocalClientFilter.class.getSimpleName());
        responseContext.getHeaders().put("CXFTestResponse", list);
    }

}
